
## CATO-CLI - mutation.sites.removeSite:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.sites.removeSite) for documentation on this operation.

### Usage for mutation.sites.removeSite:

```bash
catocli mutation sites removeSite -h

catocli mutation sites removeSite <json>

catocli mutation sites removeSite --json-file mutation.sites.removeSite.json

catocli mutation sites removeSite '{"siteId":"id"}'

catocli mutation sites removeSite '{
    "siteId": "id"
}'
```

#### Operation Arguments for mutation.sites.removeSite ####

`accountId` [ID] - (required) N/A    
`siteId` [ID] - (required) N/A    
